@@ -6,7 +6,7 @@ from flask_restful.utils import http_status_message
 
 def abort(status_code, messages=None):
     if messages is None:
-        messages = {status_code: http_status_message(status_code)}
+        messages = {'error': http_status_message(status_code)}
     response = make_response(success=False, data=messages, status_code=status_code)
     _abort(response)
 
